#include <algorithm>
#include <fstream>
#include <iostream>
#include <map>
#include <unordered_map>
#include <vector>

using namespace std;

// input data
int N;
vector<int> C;
vector<int> P;
vector<vector<int>> adj;
int sol;

struct freq_t {
    // how many times color c is present
    map<int, int> freq;
    // how many colors have frequency x
    map<int, int> freq_inv;
    // maximum frequency present in freq_inv
    int max_freq = 0;

    freq_t() {}
    freq_t(int c) {
        freq[c] = 1;
        freq_inv[1] = 1;
        max_freq = 1;
    }

    freq_t &operator+=(freq_t &&oth) {
        // small to large
        // if (freq.size() < oth.freq.size()) {
        //     swap(*this, oth);
        // }
        for (auto &[k, v] : oth.freq) {
            int old_freq = freq[k];
            freq_inv[old_freq]--;
            // keep the maps small
            if (freq_inv[old_freq] == 0) {
                freq_inv.erase(old_freq);
            }

            int new_freq = old_freq + v;
            freq[k] = new_freq;
            freq_inv[new_freq]++;

            max_freq = max(max_freq, new_freq);
        }
        return *this;
    }

    int max_freq_count() const { return freq_inv.at(max_freq); }
};

freq_t dfs(int u) {
    freq_t res(C[u]);

    for (int v : adj[u]) {
        res += dfs(v);
    }

    sol = max(sol, res.max_freq_count());
    return res;
}

int main() {
    cin >> N;
    C.resize(N);
    P.resize(N);
    adj.resize(N);

    for (int i = 0; i < N; i++) {
        // node i has color C[i]
        cin >> C[i];
    }
    for (int i = 1; i < N; i++) {
        // there is a link P[i] -> i
        // note: P[0] is undefined!
        cin >> P[i];
        adj[P[i]].push_back(i);
    }

    dfs(0);
    cout << sol << endl;

    return 0;
}
